summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/pcre2/src/pcre2_intmodedep.h
diff options
context:
space:
mode:
authorLiang Qi <liang.qi@qt.io>2019-05-07 10:52:53 +0000
committerThe Qt Project <gerrit-noreply@qt-project.org>2019-05-07 13:28:29 +0000
commit35b25bc91784f5a39ee034a99167d5bfee49f74b (patch)
treef6198a2b9f4456c05f3399d60e95da57499b0036 /src/3rdparty/pcre2/src/pcre2_intmodedep.h
parentaea6ff4f57135b0f2f076e86e22cb87c0a7014fe (diff)
parentc2b553784dfbe0ece90f79709639e27e74359a7d (diff)
Merge "Merge remote-tracking branch 'origin/5.13' into dev" into refs/staging/dev
Diffstat (limited to 'src/3rdparty/pcre2/src/pcre2_intmodedep.h')
-rw-r--r--src/3rdparty/pcre2/src/pcre2_intmodedep.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/3rdparty/pcre2/src/pcre2_intmodedep.h b/src/3rdparty/pcre2/src/pcre2_intmodedep.h
index 62626d0a8a..bf3a235984 100644
--- a/src/3rdparty/pcre2/src/pcre2_intmodedep.h
+++ b/src/3rdparty/pcre2/src/pcre2_intmodedep.h
@@ -585,6 +585,8 @@ typedef struct pcre2_real_match_context {
#endif
int (*callout)(pcre2_callout_block *, void *);
void *callout_data;
+ int (*substitute_callout)(pcre2_substitute_callout_block *, void *);
+ void *substitute_callout_data;
PCRE2_SIZE offset_limit;
uint32_t heap_limit;
uint32_t match_limit;
@@ -656,7 +658,8 @@ typedef struct pcre2_real_match_data {
PCRE2_SIZE leftchar; /* Offset to leftmost code unit */
PCRE2_SIZE rightchar; /* Offset to rightmost code unit */
PCRE2_SIZE startchar; /* Offset to starting code unit */
- uint16_t matchedby; /* Type of match (normal, JIT, DFA) */
+ uint8_t matchedby; /* Type of match (normal, JIT, DFA) */
+ uint8_t flags; /* Various flags */
uint16_t oveccount; /* Number of pairs */
int rc; /* The return code from the match */
PCRE2_SIZE ovector[131072]; /* Must be last in the structure */